@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-from .api import ListoAPI
+from .api import ListoAPI, WrongDataFormat
 
 
 class CfdiPayments(ListoAPI):
@@ -39,3 +39,19 @@ class CfdiPayments(ListoAPI):
             for i in r:
                 yield i
             kwargs["offset"] += size
+    
+    def cfdi_payments_detail(self, id_pago):
+        try:
+            assert (type(id_pago) is int), 'El campo `id_pago` debe ser tipo `int`'
+            return self.make_request(method="GET", path="/cfdi_payments/payments/" + str(id_pago)) \
+                .json()
+        except WrongDataFormat:
+            pass
+
+    def cfdi_receipts_detail(self, id_recibo):
+        try:
+            assert (type(id_recibo) is int), 'El campo `id_recibo` debe ser tipo `int`'
+            return self.make_request(method="GET", path="/cfdi_payments/receipts/" + str(id_recibo)) \
+                .json()
+        except WrongDataFormat:
+            pass        
